Class: Specify::Model::Accession

Inherits:
Object
  • Object
show all
Includes:
Createable, Updateable
Defined in:
lib/specify/models/accession.rb

Overview

Accessions are interactions that represent the formal transferral of ownership of one or more #collection_objects (instances of Specify::Model::CollectionObjects).

An Accession belongs to a #division (an instance of Specify::Model::Division).

Instance Method Summary collapse

Methods included from Updateable

#before_update

Methods included from Createable

#before_create

Instance Method Details

#numberObject

Returns a String with the accession number (a number under which all information relating to an accession is filed).



28
29
30
# File 'lib/specify/models/accession.rb', line 28

def number
  self[:AccessionNumber]
end