Class: Specify::Model::AdministrativeDivision

Inherits:
Object
  • Object
show all
Includes:
Updateable
Defined in:
lib/specify/models/geography/administrative_division.rb

Overview

AdministrativeDivision is the rank class for the Specify::Model::Geography tree. An AdministrativeDivision holds information about a formal political subdivison in a geographic tree.

A AdministrativeDivision has a parent (another instance of AdministrativeDivision) unless it is the root rank of the tree and can have one child (another instance of AdministrativeDivision).

Instance Method Summary collapse

Methods included from Updateable

#before_update

Instance Method Details

#nameObject

Returns a String with the name of the formal political subdivision.



27
28
29
# File 'lib/specify/models/geography/administrative_division.rb', line 27

def name
  self.Name
end