Class: Specify::Model::AppResourceDir

Inherits:
Object
  • Object
show all
Includes:
Createable, Updateable
Defined in:
lib/specify/models/app_resource_dir.rb

Overview

AppResourceDirs associate instances of Specify::Model::ViewSetObject or AppResource (not implemented) with other Specify::Model classes, such as Specify::Model::Collection, Specify::Model::Discipline, or Specify::Model::User, as well as the abstract/custom Specify::UserType, and are used to locate a relevant ViewSetObject or AppResource for a given instance of one of these classes.

Resources (ViewSetObjects or AppResurces) are usually XML files used by the Specify application. The files are stored in the AppResourceDirs associated #view_set_object’s or AppResource (not implemented) Specify::Model::AppResourceData.

Instance Method Summary collapse

Methods included from Updateable

#before_update

Methods included from Createable

#before_create

Instance Method Details

#discipline_typeObject

Returns a String that is the discipline type (same as Specify::Model::Discipline#name) self belongs to.



38
39
40
# File 'lib/specify/models/app_resource_dir.rb', line 38

def discipline_type
  self[:DisciplineType]
end