Class: Specify::Model::Accession
- Inherits:
-
Object
- Object
- Specify::Model::Accession
- Includes:
- Createable, Updateable
- Defined in:
- lib/specify/models/accession.rb
Overview
Accessions are interactions that represent the formal transferral of ownership of one or more #collection_objects (instances of Specify::Model::CollectionObjects).
An Accession belongs to a #division (an instance of Specify::Model::Division).
Instance Method Summary collapse
-
#number ⇒ Object
Returns a String with the accession number (a number under which all information relating to an accession is filed).
Methods included from Updateable
Methods included from Createable
Instance Method Details
#number ⇒ Object
Returns a String with the accession number (a number under which all information relating to an accession is filed).
28 29 30 |
# File 'lib/specify/models/accession.rb', line 28 def number self[:AccessionNumber] end |