Class: Specify::Model::Division
- Inherits:
-
Object
- Object
- Specify::Model::Division
- Includes:
- Updateable
- Defined in:
- lib/specify/models/division.rb
Overview
Divisions are the next highest level of scope within a Specify::Database.
A Division belongs to the single instance of Specify::Model::Institution within a Specify::Database.
A Division has one or more instances of Specify::Model::Discipline.
Specify::Model::Agent instances are scoped to the Division level.