Class: Specify::Model::Geography
- Inherits:
-
Object
- Object
- Specify::Model::Geography
- Includes:
- TreeQueryable, Updateable
- Defined in:
- lib/specify/models/geography/geography.rb
Overview
Geography is the tree class for the geographic tree. Geographies hold all Specify::Model::AdministrativeDivision and Specify::Model::GeographicName instances belonging to a geography used by a Specify::Model::Discipline.
Constant Summary
Constants included from TreeQueryable
TreeQueryable::AMBIGUOUS_MATCH_ERROR