Class: Specify::Model::Institution
- Inherits:
-
Object
- Object
- Specify::Model::Institution
- Includes:
- Updateable
- Defined in:
- lib/specify/models/institution.rb
Overview
Institution is the highest level of scope within a Specify::Database.
A Specify::Database has a single instance of Institution. The Institution has one or more instances of Specify::Model::Division.