Class: Specify::Model::Taxonomy
- Inherits:
-
Object
- Object
- Specify::Model::Taxonomy
- Includes:
- TreeQueryable, Updateable
- Defined in:
- lib/specify/models/taxonomy/taxonomy.rb
Overview
Taxnomy is the tree class for the taxonomy tree. Taxonomies hold all Specify::Model::Rank and Specify::Model::Taxon instances belonging to a taxonomy used by a Specify::Model::Discipline.
Constant Summary
Constants included from TreeQueryable
Specify::Model::TreeQueryable::AMBIGUOUS_MATCH_ERROR